# SteelEagle SDK: Controller Library for SteelEagle Vehicles

The SteelEagle SDK provides a programming interface for SteelEagle-compliant vehicles.
Users can send messages over the native API, using gRPC and Protobuf, or use higher level
primitives through Pydantic. This package also provides a compiler for SteelEagle DSL (.dsl)
files.

## License
SteelEagle SDK is released under GPL-2.0.

## Supported Platforms
Linux
